@@ -1,5 +1,3 @@
-from operator import index
-from nbformat import read
 import pandas as pd
 from wencaipy.common.wcParameter import SQLITE_PATH_RR_PC 
 
